GridSpectra
===========

.. currentmodule:: GridPolator

.. autoclass:: GridSpectra
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~GridSpectra.evaluate
      ~GridSpectra.from_st
      ~GridSpectra.from_vspec

   .. rubric:: Methods Documentation

   .. automethod:: evaluate
   .. automethod:: from_st
   .. automethod:: from_vspec
